==> antv__x6-1.25.3.jar: META-INF/resources/webjars/antv__x6/1.25.3/lib/registry/marker/diamond.js <==
"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.diamond = void 0;
var geometry_1 = require("../../geometry");
var util_1 = require("./util");
var diamond = function (_a) {
    var size = _a.size, width = _a.width, height = _a.height, offset = _a.offset, attrs = __rest(_a, ["size", "width", "height", "offset"]);
    var s = size || 10;
    var w = width || s;
    var h = height || s;
    var path = new geometry_1.Path();
    path
        .moveTo(0, h / 2)
        .lineTo(w / 2, 0)
        .lineTo(w, h / 2)
        .lineTo(w / 2, h)
        .close();
    return __assign(__assign({}, attrs), { tagName: 'path', d: util_1.normalize(path.serialize(), offset == null ? -w / 2 : offset) });
};
exports.diamond = diamond;
//# sourceMappingURL=diamond.js.map

==> antv__x6-1.34.1.jar: META-INF/resources/webjars/antv__x6/1.34.1/lib/registry/marker/diamond.js <==
"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.diamond = void 0;
var geometry_1 = require("../../geometry");
var util_1 = require("./util");
var diamond = function (_a) {
    var size = _a.size, width = _a.width, height = _a.height, offset = _a.offset, attrs = __rest(_a, ["size", "width", "height", "offset"]);
    var s = size || 10;
    var w = width || s;
    var h = height || s;
    var path = new geometry_1.Path();
    path
        .moveTo(0, h / 2)
        .lineTo(w / 2, 0)
        .lineTo(w, h / 2)
        .lineTo(w / 2, h)
        .close();
    return __assign(__assign({}, attrs), { tagName: 'path', d: (0, util_1.normalize)(path.serialize(), offset == null ? -w / 2 : offset) });
};
exports.diamond = diamond;
//# sourceMappingURL=diamond.js.map
